@@ -55,6 +55,8 @@ class File:
                 else:
                     items.append([x.decode(encoding).encode('utf-8') for x in c])
             # csv.unregister_dialect('my_dialect')
+            if to_json is False:
+                items = [keys] + items
             return items
         if file_type == 'json':
             return json.loads(text)
